.. _apps-data:

=================
Data Stores
=================

.. warning::

    This is an experimental module, by any means complete.
    Use at your own risk.


.. automodule:: pulsar.apps.data


.. toctree::
   :maxdepth: 2

   clients
   stores
